@@ -1,9 +1,11 @@
 
 import cv2 as cv
-from Point import Point
-from DetectedArea import DetectedArea
-from DetectedArea import DetectedFace
-from helperFunctions import *
+import Point
+import DetectedArea
+import DetectedFace
+
+import HelperFunctions
+
 import numpy as np
 
 
@@ -72,7 +74,7 @@ class ImageManager:
 
         # finding objects in then given angle degree rotated image
        
-        rotatedGrayImage = rotateCounterClockwise(self.grayImage, angle)
+        rotatedGrayImage = HelperFunctions.rotateCounterClockwise(self.grayImage, angle)
             
         # Collecting raw detected objects received from detectMultiScale
         rawObjs = detector.detectMultiScale(rotatedGrayImage, scaleFactor = scaleFactor, minNeighbors = minNeighbors, minSize = minDimensions, maxSize = maxDimensions)
@@ -290,7 +292,7 @@ class ImageManager:
             faceOrigin = Point((leftEye.center.x + rightEye.center.x)/2,(leftEye.center.y + rightEye.center.y)/2)
            
             # Rotate the face origin point and the image such that the face is straightened up
-            rotatedGrayImage = rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
+            rotatedGrayImage = HelperFunctions.rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
             rotatedImageCenter = Point(rotatedGrayImage.shape[1]/2, rotatedGrayImage.shape[0]/2)
             rotatedFaceOrigin = faceOrigin.rotatePointClockwise(originalImageCenter, relativeCounterClockwiseAngle)
             rotatedFaceOrigin = rotatedFaceOrigin.projectPoint(originalImageCenter, rotatedImageCenter)
@@ -298,11 +300,11 @@ class ImageManager:
             
             
             # DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- 
-            debugOriginalImage = rotateClockwise(self.image, 0)
+            debugOriginalImage = HelperFunctions.rotateClockwise(self.image, 0)
             leftEye.draw(debugOriginalImage, (255,0,255), 2)
             rightEye.draw(debugOriginalImage, (0,255,255), 2)
             cv.circle(debugOriginalImage, faceOrigin.exportCoordinates(), 0, (0, 255, 0), 20)
-            debugRotatedOriginalImage = rotateClockwise(debugOriginalImage, relativeCounterClockwiseAngle)
+            debugRotatedOriginalImage = HelperFunctions.rotateClockwise(debugOriginalImage, relativeCounterClockwiseAngle)
             cv.circle(debugRotatedOriginalImage, rotatedFaceOrigin.exportCoordinates(), 0, (255, 255, 255), 12)
             # DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- 
             
@@ -351,7 +353,7 @@ class ImageManager:
 
             if len(detectedFaces) == 0:
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -373,7 +375,7 @@ class ImageManager:
                     continue
 
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -405,7 +407,7 @@ class ImageManager:
 
             # Convert biggestFace coordinates from being in the cropped image to the original image
             biggestFace.draw(debugRotatedCrop, (0, 0, 255), 2)
-            cv.imshow("Potential face " + str(debugPotentialFaceNumber), resizeMinTo(debugRotatedCrop, 250))
+            cv.imshow("Potential face " + str(debugPotentialFaceNumber), HelperFunctions.resizeMinTo(debugRotatedCrop, 250))
 
             debugArrayFaces.append((biggestFace.copy(), rotatedFaceCenter, croppedCenter, rotatedImageCenter, relativeCounterClockwiseAngle, originalImageCenter)) 
                 
@@ -448,7 +450,7 @@ class ImageManager:
             faceOrigin = Point((leftEye.center.x + rightEye.center.x)/2,(leftEye.center.y + rightEye.center.y)/2)
            
             # Rotate the face origin point and the image such that the face is straightened up
-            rotatedGrayImage = rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
+            rotatedGrayImage = HelperFunctions.rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
             rotatedImageCenter = Point(rotatedGrayImage.shape[1]/2, rotatedGrayImage.shape[0]/2)
             rotatedFaceOrigin = faceOrigin.rotatePointClockwise(originalImageCenter, relativeCounterClockwiseAngle).projectPoint(originalImageCenter, rotatedImageCenter)
 
@@ -481,7 +483,7 @@ class ImageManager:
             # if found no faces right side up
             if len(detectedFaces) == 0:
                 # Scan the image upside down
-                rotatedCrop = rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -503,7 +505,7 @@ class ImageManager:
                     continue
 
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
