@@ -1,9 +1,11 @@
 import cv2 as cv
 from numpy import append
-from DetectedArea import DetectedArea, DetectedFace
-from ImageManager import ImageManager
-from Point import Point
-from helperFunctions import *
+import numpy as np
+import DetectedArea
+import DetectedFace
+import ImageManager
+import Point
+import HelperFunctions
 import time
 import threading
 import queue
@@ -59,7 +61,7 @@ class VideoManager:
                 break
             # Our operations on the frame come here
             start = time.time()
-            frame = resizeMinTo500(frame)
+            frame = HelperFunctions.resizeMinTo500(frame)
             print(f"DEBUG resize time {time.time() - start}")
 
             # Display the resulting frame
@@ -130,7 +132,7 @@ class VideoManager:
                 # Our operations on the frame come here
                 debug_frameCount = debug_frameCount + 1
 
-                frame = resizeMinTo500(frame)
+                frame = HelperFunctions.resizeMinTo500(frame)
 
                 # startTime = time.time()
                 grayFrame = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
@@ -214,7 +216,7 @@ class VideoManager:
                 # Our operations on the frame come here
                 debug_frameCount = debug_frameCount + 1
 
-                frame = resizeMinTo500(frame)
+                frame = HelperFunctions.resizeMinTo500(frame)
                 frameMgnr = ImageManager(frame)
                 # startTime = time.time()
                 faces = frameMgnr.findFacesCounterClockwiseMultipleAngles(
@@ -295,7 +297,7 @@ class VideoManager:
                     continue
 
                 # resizing the frame to fit my tiny monitor, and to increase haarcascade detection performance too ye
-                frame = resizeMinTo500(frame)
+                frame = HelperFunctions.resizeMinTo500(frame)
 
                 # set new display time target (next_frame) after check if new frame is available instead of before. This is to make sure when live capturing
                 # the newest image will be shown as soon as they are ready (variable fps maybe). If this was to be put before checking if new frame is available, newest
@@ -405,7 +407,7 @@ class VideoManager:
                 
                 startTime = time.time()
                 # resizing the frame to fit my tiny monitor, and to increase haarcascade detection performance too ye
-                min500frame = resizeMinTo500(frame)
+                min500frame = HelperFunctions.resizeMinTo500(frame)
                 resizeTime = time.time() - startTime
 
                 # set new display time target (next_frame) after check if new frame is available instead of before. This is to make sure when live capturing
@@ -500,7 +502,7 @@ class VideoManager:
                             # rotate clockwise because the face's angle is the counter clockwise angle of the right eye to the left eye
                             frameOrigin = Point(
                                 min500frame.shape[1]/2, min500frame.shape[0]/2)
-                            rotatedFrame = rotateClockwise(
+                            rotatedFrame = HelperFunctions.rotateClockwise(
                                 min500frame, counterClockwiseAngle)
                             rotatedFrameOrigin = Point(
                                 rotatedFrame.shape[1]/2, rotatedFrame.shape[0]/2)
@@ -547,7 +549,7 @@ class VideoManager:
                                 croppedPotentialFace, cv.COLOR_BGR2GRAY)
                             # run basic haarcascade facial detection on it
                             # CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ?
-                            detectedFaces = haarcascade_FacialDetection(
+                            detectedFaces = HelperFunctions.haarcascade_FacialDetection(
                                 grayCroppedPotentialFace, 1.3, 6)
 
                             # if found nothing then move to the next face's last frame location
@@ -590,7 +592,7 @@ class VideoManager:
                             # CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ? CAN IMPROVE PERFORMANCE BY ADDING APPROPRIATE MINSIZE AND MAXSIZE ?
 
                             # find the eyes
-                            tempEyesArray = haarcascade_EyeDetection(
+                            tempEyesArray = HelperFunctions.haarcascade_EyeDetection(
                                 grayCroppedPotentialFace, 1.3, 10)
                             detectedEyes = []
 
